@@ -12,7 +12,7 @@ except ImportError:
 
 GIT_HOST = 'api.djangy.com'
 API_BASE_URL = 'https://api.djangy.com'
-VERSION = '0.13'
+VERSION = '0.14'
 
 HOME = None
 if platform.system() == 'Windows':
@@ -263,7 +263,7 @@ def validate_pubkey(pubkey_path):
 def get_pubkey():
     # try to find public key path
     pubkey_path = None
-    if os.path.exists('%s/.ssh/id_rsa.pub' % HOMe):
+    if os.path.exists('%s/.ssh/id_rsa.pub' % HOME):
         pubkey_path = '%s/.ssh/id_rsa.pub' % HOME
     else:
         is_valid_pubkey = False
